==> ciao-4.6-src-core.tar.gz: ciao-4.6/src/common/smoke/bin/ds9-smoke001.sh <==
#!/bin/sh

TESTID=ds9-smoke001
export TESTID

#
# Replace with variable via configure
#
ASCDS_QUIET=1; export ASCDS_QUIET
ASCDS_OVERRIDE=1; export ASCDS_OVERRIDE
. setup.sh

#
# Setup test env
#
TESTDIR=$ASCDS_INSTALL/test/smoke/data; export TESTDIR
if [ "$ASCDS_SMOKE_DIR" = "" ]; then
   OUTDIR=$ASCDS_WORK_PATH/smoke.${LOGNAME}/$TESTID; export OUTDIR
else
   OUTDIR=$ASCDS_SMOKE_DIR/smoke.${LOGNAME}/$TESTID; export OUTDIR
fi
SAVEDIR=$TESTDIR/; export SAVEDIR

INDIR=$TESTDIR

OUTFILE=${OUTDIR}/${TESTID}.txt

if test -d $OUTDIR
then
   \rm -rf $OUTDIR
fi
mkdir -p $OUTDIR

#
# Run command
#
printf "Running test $TESTID "

printf "."
ds9="ds9smoke$$"
ds9 -title $ds9 $ASCDS_INSTALL/test/smoke/data/acisf04425_000N003_evt1.fits &
sleep 2
n=1
while test $n -lt 180
do
  if test `xpaaccess $ds9` = yes
  then
     break;
  fi
  sleep 1
  n=`expr $n + 1`
done

xpaset -p $ds9 bin about 3800 3800 2>/dev/null
xpaset -p $ds9 bin factor 2 2>/dev/null
xpaset -p $ds9 scale log 2>/dev/null
xpaset -p $ds9 cmap b 2>/dev/null
xpaset -p $ds9 contour yes 2>/dev/null
xpaset -p $ds9 contour limits 1 100 2>/dev/null
xpaset -p $ds9 contour smooth 5 2>/dev/null
xpaset -p $ds9 contour nlevels 6 2>/dev/null
\rm -f $OUTFILE
xpaset -p $ds9 contour save $OUTFILE 2>/dev/null
xpaset -p $ds9 quit 2>/dev/null
touch $OUTFILE

#
# Run checks on the output files.
#
state=0
printf "."
\rm -f ${OUTFILE}.fix ${OUTFILE}.fix2
cat  "$OUTFILE" | sed s/..e/00e/g > ${OUTFILE}.fix
cat "$SAVEDIR/${TESTID}.txt" | sed s/..e/00e/g > ${OUTFILE}.fix2
diff ${OUTFILE}.fix ${OUTFILE}.fix2 >> $OUTDIR/diff.log 2>&1
if test $? != 0
then
   state=1
fi
\rm -f ${OUTFILE}.fix ${OUTFILE}.fix2
printf ". "

#
# Exit condition
#
if test $state = 0
then
  echo "PASS"

  if echo "$OUTDIR" | grep "$TESTID" >/dev/null
  then
     rm $OUTDIR/${TESTID}.*
     rm $OUTDIR/diff.log
     rmdir $OUTDIR
  fi
else
  echo "FAIL"
fi

exit $state

==> ciao-4.8-src-core.tar.gz: ciao-4.8/src/common/smoke/bin/ds9-smoke001.sh <==
#!/bin/sh

TESTID=ds9-smoke001
export TESTID

#
# Replace with variable via configure
#
ASCDS_QUIET=1; export ASCDS_QUIET
ASCDS_OVERRIDE=1; export ASCDS_OVERRIDE
. setup.sh

#
# Setup test env
#
TESTDIR=$ASCDS_INSTALL/test/smoke/data; export TESTDIR
if [ "$ASCDS_SMOKE_DIR" = "" ]; then
   OUTDIR=$ASCDS_WORK_PATH/smoke.${LOGNAME}/$TESTID; export OUTDIR
else
   OUTDIR=$ASCDS_SMOKE_DIR/smoke.${LOGNAME}/$TESTID; export OUTDIR
fi
SAVEDIR=$TESTDIR/; export SAVEDIR

INDIR=$TESTDIR

OUTFILE=${OUTDIR}/${TESTID}.txt

if test -d $OUTDIR
then
   \rm -rf $OUTDIR
fi
mkdir -p $OUTDIR

#
# Run command
#
printf "Running test $TESTID "

printf "."
ds9="ds9smoke$$"
ds9 -title $ds9 $ASCDS_INSTALL/test/smoke/data/acisf04425_000N003_evt1.fits &
sleep 3
n=1
while test $n -lt 180
do
  if test `xpaaccess $ds9` = yes
  then
     break;
  fi
  sleep 2
  n=`expr $n + 1`
done

xpaset -p $ds9 bin about 3800 3800 2>/dev/null
xpaset -p $ds9 bin factor 2 2>/dev/null
xpaset -p $ds9 scale log 2>/dev/null
xpaset -p $ds9 cmap b 2>/dev/null
xpaset -p $ds9 contour yes 2>/dev/null
xpaset -p $ds9 contour limits 1 100 2>/dev/null
xpaset -p $ds9 contour smooth 5 2>/dev/null
xpaset -p $ds9 contour nlevels 6 2>/dev/null
\rm -f $OUTFILE
xpaset -p $ds9 contour save $OUTFILE 2>/dev/null
xpaset -p $ds9 quit 2>/dev/null
touch $OUTFILE

#
# Run checks on the output files.
#
state=0
printf "."
\rm -f ${OUTFILE}.fix ${OUTFILE}.fix2
cat "$OUTFILE" | sed s/..e/00e/g | grep -v "missing on display" > ${OUTFILE}.fix
cat "$SAVEDIR/${TESTID}.txt" | sed s/..e/00e/g | grep -v "missing on display" > ${OUTFILE}.fix2
diff ${OUTFILE}.fix ${OUTFILE}.fix2 >> $OUTDIR/diff.log 2>&1
if test $? != 0
then
   state=1
fi
\rm -f ${OUTFILE}.fix ${OUTFILE}.fix2
printf ". "

#
# Exit condition
#
if test $state = 0
then
  echo "PASS"

  if echo "$OUTDIR" | grep "$TESTID" >/dev/null
  then
     rm $OUTDIR/${TESTID}.*
     rm $OUTDIR/diff.log
     rmdir $OUTDIR
  fi
else
  echo "FAIL"
fi

exit $state
